<?php
/*
Plugin Name: Post URLs Exporter
Plugin URI: 
Description: 导出所有文章URL为TXT文件
Version: 1.2
Author: Your Name
Author URI: 
*/

// 注册初始化钩子
add_action('admin_init', 'pue_handle_export');

// 添加独立菜单
add_action('admin_menu', 'pue_add_admin_menu');

function pue_add_admin_menu() {
    add_menu_page(
        '文章URL导出',         // 页面标题
        'URL导出',            // 菜单名称
        'export',             // 权限
        'post-urls-exporter', // 菜单slug
        'pue_export_page',    // 回调函数
        'dashicons-admin-links', 
        6                    
    );
}

// 处理导出请求
function pue_handle_export() {
    if (!isset($_POST['pue_export'])) return;

    // 权限验证
    if (!current_user_can('export') || !check_admin_referer('pue_export_nonce')) {
        wp_die('非法请求');
    }

    // 开始输出缓冲
    ob_start();
    
    // 生成导出内容
    $urls = [];
    $args = [
        'post_type'      => 'post',
        'post_status'    => 'publish',
        'posts_per_page' => -1,
        'orderby'        => 'date',
        'order'          => 'ASC'
    ];

    $query = new WP_Query($args);
    
    if ($query->have_posts()) {
        while ($query->have_posts()) {
            $query->the_post();
            $urls[] = get_permalink();
        }
    }
    wp_reset_postdata();

    // 清理缓冲并准备输出
    ob_end_clean();
    
    // 设置HTTP头
    header('Content-Type: text/plain; charset=utf-8');
    header('Content-Disposition: attachment; filename="post-urls-' . date('Y-m-d') . '.txt"');
    
    // 显式使用UNIX换行符
    echo implode("\n", $urls);
    exit; // 必须终止执行
}

// 后台显示页面
function pue_export_page() {
    $count = wp_count_posts('post')->publish;
    ?>
    <div class="wrap">
        <h1>导出文章URL</h1>
        <form method="post">
            <?php wp_nonce_field('pue_export_nonce'); ?>
            <p>当前共有 <?php echo number_format($count); ?> 篇文章</p>
            <p>
                <input type="submit" name="pue_export" 
                       class="button button-primary" 
                       value="导出为TXT文件">
            </p>
        </form>
    </div>
    <?php
}